# Fabrizio Gilardi (2010), "Who learns from what in policy diffusion processes?" AJPS 54(3)
# Replication of Table 1 (Models 1-5)


# Load packages

library(lme4)


# Load data
d0 <- read.table('data.csv', sep=',', header=TRUE)

# Create partisan variable
d0$part_a <- (d0$rightc_a - d0$leftc_a)/100
d0$part_b <- (d0$rightc_b - d0$leftc_b)/100

# Remove same-country dyads
d0 <- d0[d0$samecountry==0, ]

# Remove dyads for which imitation is "impossible"
d <- d0[d0$uerrd_b< 0, ]


# Model 1
m.1 <- lmer(imit ~ part_a + ue_b + vote_b + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d, family='binomial')
summary(m.1)

# Model 2
m.2 <- lmer(imit ~ part_a + ue_b + vote_b  + part_a*vote_b + part_a*ue_b + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d, family='binomial')
summary(m.2)

# Model 3
m.3 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b + samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d, family='binomial')
summary(m.3)

# Model 4
m.4 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b + samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + I((year-1979)/10) + I(((year-1979)^2)/100)  + I(((year-1979)^3)/10000), data=d, family='binomial')
summary(m.4)

# Model 5
m.5 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d0, family='binomial')
summary(m.5)



